pub struct ChainSpec { /* private fields */ }Expand description
Chain-spec builder representation
Multiple options are supported, and the current order is:
IF [asset_location] is some -> Use this chain_spec by copying the file from AssetLocation
ELSE IF [runtime_location] is some -> generate the chain-spec using the sc-chain-spec builder.
ELSE -> Fallback to use the default or customized cmd.
Implementations
Sourceimpl ChainSpec
impl ChainSpec
Sourcepub async fn build<'a, T>(
&mut self,
ns: &DynNamespace,
scoped_fs: &ScopedFilesystem<'a, T>,
) -> Result<(), GeneratorError>where
T: FileSystem,
pub async fn build<'a, T>(
&mut self,
ns: &DynNamespace,
scoped_fs: &ScopedFilesystem<'a, T>,
) -> Result<(), GeneratorError>where
T: FileSystem,
Build the chain-spec
Chain spec generation flow: if chain_spec_path is set -> use this chain_spec else if runtime_path is set and cmd is compatible with chain-spec-builder -> use the chain-spec-builder else if chain_spec_command is set -> use this cmd for generate the chain_spec else -> use the default command.
pub async fn build_raw<'a, T>(
&mut self,
ns: &DynNamespace,
scoped_fs: &ScopedFilesystem<'a, T>,
relay_chain_id: Option<Chain>,
) -> Result<(), GeneratorError>where
T: FileSystem,
Sourcepub async fn override_code<'a, T>(
&mut self,
scoped_fs: &ScopedFilesystem<'a, T>,
wasm_override: &AssetLocation,
) -> Result<(), GeneratorError>where
T: FileSystem,
pub async fn override_code<'a, T>(
&mut self,
scoped_fs: &ScopedFilesystem<'a, T>,
wasm_override: &AssetLocation,
) -> Result<(), GeneratorError>where
T: FileSystem,
Override the :code in chain-spec raw version
pub async fn read_raw_spec<'a, T>(
&self,
scoped_fs: &ScopedFilesystem<'a, T>,
) -> Result<Value, GeneratorError>where
T: FileSystem,
pub async fn override_raw_spec<'a, T>(
&mut self,
scoped_fs: &ScopedFilesystem<'a, T>,
raw_spec_overrides: &JsonOverrides,
) -> Result<(), GeneratorError>where
T: FileSystem,
pub async fn find_raw_key<'a, T>(
&self,
scoped_fs: &ScopedFilesystem<'a, T>,
key: &str,
) -> Result<bool, GeneratorError>where
T: FileSystem,
pub fn raw_path(&self) -> Option<&Path>
pub fn set_asset_location(&mut self, location: AssetLocation)
pub async fn read_chain_id<'a, T>(
&self,
scoped_fs: &ScopedFilesystem<'a, T>,
) -> Result<String, GeneratorError>where
T: FileSystem,
pub async fn customize_para<'a, T>(
&self,
para: &ParachainSpec,
relay_chain_id: &str,
scoped_fs: &ScopedFilesystem<'a, T>,
) -> Result<(), GeneratorError>where
T: FileSystem,
pub async fn customize_relay<'a, T, U>( &self, relaychain: &RelaychainSpec, hrmp_channels: &[HrmpChannelConfig], para_artifacts: Vec<ParaGenesisConfig<U>>, scoped_fs: &ScopedFilesystem<'a, T>, ) -> Result<(), GeneratorError>
pub async fn add_bootnodes<'a, T>(
&self,
scoped_fs: &ScopedFilesystem<'a, T>,
bootnodes: &[String],
) -> Result<(), GeneratorError>where
T: FileSystem,
Sourcepub fn chain_id_from_spec(spec_content: &str) -> Result<String, GeneratorError>
pub fn chain_id_from_spec(spec_content: &str) -> Result<String, GeneratorError>
Get the chain_is from the json content of a chain-spec file.
Sourcepub async fn run_post_process_script<'a, T>(
&self,
script_command: &str,
scoped_fs: &ScopedFilesystem<'a, T>,
) -> Result<(), GeneratorError>where
T: FileSystem,
pub async fn run_post_process_script<'a, T>(
&self,
script_command: &str,
scoped_fs: &ScopedFilesystem<'a, T>,
) -> Result<(), GeneratorError>where
T: FileSystem,
Run a post-processing script on the chain-spec file. The script receives the path to the chain-spec as argument.